==> billogram-foundation-3.13.10.tgz: package/modules/components/radio/RadioButtonGroupContainer.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { Provider } from 'react-redux';
import { mount } from 'enzyme';

import RadioButtonGroup from './RadioButtonGroup';
import RadioButtonGroupContainer, { changeType } from './RadioButtonGroupContainer';

import radioButtonGroupChange from './redux/radioButtonGroupChange';
import radioButtonGroupState from './redux/radioButtonGroupState';
import radioButtonOptionState from './redux/radioButtonOptionState';

import createStore from '../../test-utils/createStore';


const TestRadioButtonGroup = RadioButtonGroup({
    block: purebem.of('test-radio-button-group'),
    displayName: 'TestRadioButtonGroup'
});

const TestRadioButtonGroupContainer = RadioButtonGroupContainer({
    Component: TestRadioButtonGroup
});

const actionTypePrefix = 'TEST-RADIO-BUTTON-GROUP';
const path = 'component';
const root = 'test';

test('should dispatch change event on change', () => {
    const store = createStore({
        [root]: {
            [path]: radioButtonGroupState({
                options: [
                    radioButtonOptionState({
                        value: 'a'
                    }),
                    radioButtonOptionState({
                        value: 'b'
                    })
                ],
                value: 'a'
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestRadioButtonGroupContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );

    const options = provider.find('TestRadioButtonGroupOption');
    expect(options.length).toBe(2);

    options.at(1).simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(radioButtonGroupChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: 'b'
    }));
});

test('should read value from store', () => {
    const options = [
        radioButtonOptionState({
            value: 'a'
        }),
        radioButtonOptionState({
            value: 'b'
        })
    ];

    const store = createStore({
        [root]: {
            [path]: radioButtonGroupState({
                options,
                value: 'a'
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestRadioButtonGroupContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );

    expect(provider.find(TestRadioButtonGroup).prop('value')).toBe('a');
    expect(provider.find(TestRadioButtonGroup).prop('options')).toEqual(options);
});

==> billogram-foundation-4.6.4.tgz: package/modules/components/radio/RadioButtonGroupContainer.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { Provider } from 'react-redux';
import { mount } from 'enzyme';

import RadioButtonGroup from './RadioButtonGroup';
import RadioButtonGroupContainer, { changeType } from './RadioButtonGroupContainer';

import radioButtonGroupChange from './redux/radioButtonGroupChange';
import radioButtonGroupState from './redux/radioButtonGroupState';
import radioButtonOptionState from './option-default/radioButtonOptionState';

import createStore from '../../test-utils/createStore';


const TestRadioButtonGroup = RadioButtonGroup({
    block: purebem.of('test-radio-button-group'),
    displayName: 'TestRadioButtonGroup'
});

const TestRadioButtonGroupContainer = RadioButtonGroupContainer({
    Component: TestRadioButtonGroup
});

const actionTypePrefix = 'TEST-RADIO-BUTTON-GROUP';
const path = 'component';
const root = 'test';

test('should dispatch change event on change', () => {
    const store = createStore({
        [root]: {
            [path]: radioButtonGroupState({
                options: [
                    radioButtonOptionState({
                        value: 'a'
                    }),
                    radioButtonOptionState({
                        value: 'b'
                    })
                ],
                value: 'a'
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestRadioButtonGroupContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );

    const options = provider.find('TestRadioButtonGroupOption');
    expect(options.length).toBe(2);

    options.at(1).simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(radioButtonGroupChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: 'b'
    }));
});

test('should read value from store', () => {
    const options = [
        radioButtonOptionState({
            value: 'a'
        }),
        radioButtonOptionState({
            value: 'b'
        })
    ];

    const store = createStore({
        [root]: {
            [path]: radioButtonGroupState({
                options,
                value: 'a'
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestRadioButtonGroupContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );

    expect(provider.find(TestRadioButtonGroup).prop('value')).toBe('a');
    expect(provider.find(TestRadioButtonGroup).prop('options')).toEqual(options);
});
